library("exams")
oopt <- options(device.ask.default = FALSE, exams_tex = "tinytex") # exams_tex = "tools"

# PASO 1: CAMBIAR LOS VALORES DE LAS SIGUIENTES OPCIONES -------------
# Cambiar la semilla cuando se quieren generar una colección diferente
semilla = 1234  
# cuántos exámenes distintos se generan 
#   (2 o 3 para las pruebas iniciales, 
#     luego un valor relacionado con el número de alumnos)
numcopias = 3
# número de intentos que tiene el alumno para realizar el examen
numintentos = 1 
# nombre de los ficheros que se generan
nombreexamen = "Asignatura01-20200415-" 
# qué salidas: 
VsalidaHTML = TRUE  # FALSE
VsalidaPDF = FALSE  # FALSE
# Personalizar:
Vfecha = "2020-04-15"
# LOS SIGUIENTES NO SE RECOMIENDA MODIFICARLOS
# directorios:
## directorio "dir"
Vdir = "exagenerados"
  Vedir = "bancopreguntas"
Vsdir = "exagenerados_extras"
Vtexdir = "exagenerados_latex"
if (!file.exists(Vedir)) {
  #unlink(Vedir,recursive = TRUE)
  dir.create(Vedir)
}  
if (!file.exists(Vsdir)) {
  #unlink(Vsdir,recursive = TRUE)
  dir.create(Vsdir)
}  
if (!file.exists(Vsdir)) {
  #unlink(Vsdir,recursive = TRUE)
  dir.create(Vsdir)
} else {
  unlink(Vsdir,recursive = TRUE)
  dir.create(Vsdir)
}  




# PASO 2: Selección de preguntas -----------
# Se completará con los nombres de ficheros que contienen las preguntas que
# se quieren incluir en el examen

## ATENCIÓN: ACTUALMENTE exams NO SOPORTA EN LA SALIDA BLACKBOARD
##    LA CREACIÓN DE PREGUNTAS TIPO: cloze
miexamen = list(
  # Pregunta 1
  "bancopreguntas/demosexams/boxplots.Rmd",
  # Pregunta 2
  "bancopreguntas/demosexams/confint.Rmd",
  # Pregunta 3  (elige una pregunta al azar de la lista que aparece)
   c("bancopreguntas/demosexams/tstat.Rmd",
     "bancopreguntas/demosexams/tstat2.Rmd"),
  # Pregunta 4
  "bancopreguntas/demosexams/deriv.Rmd",
  # Pregunta 5  (elige una pregunta al azar de la lista que aparece)
   c("bancopreguntas/demosexams/fruit.Rmd",
     "bancopreguntas/demosexams/fruit2.Rmd"),
  # Pregunta 6
  "bancopreguntas/demosexams/essayreg.Rmd",
  # Pregunta 7
  "bancopreguntas/demosexams/Rlogo.Rmd"    # EL ÚLTIMO NO LLEVA ","
)

# PASO 3: PULSAR EL BOTÓN DE LA PARTE SUPERIOR DERECHA: "Source" 
###         PARA GENERAR TODOS LOS EXÁMENES


## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## 
## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## 
## NO ES NECESARIO MODIFICAR LOS SIGUIENTES APARTADOS
## ÚNICAMENTE SE PODRÍA BORRAR EL CÓDIGO DE UNA DE LAS SALIDAS AUXILIARES: PDF O HTML
## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## 



# Creación del examen en formato Blackboard ----------------

set.seed(semilla)

exams2blackboard(miexamen, 
     n = numcopias, # cuántos exámenes distintos que se generan (relacionado con el número de alumnos)
     name = paste0(nombreexamen,"BBEV"), # nombre del fichero zip que se genera
     dir = Vdir,  # directorio donde se colocarán los ficheros generados FINALES
     edir = Vedir, # directorio principal del banco de preguntas
     sdir=Vsdir, # directorio donde se colocarán los ficheros extras generados relacionados con los ejercicios incluidos
     maxattempts = numintentos  # número de intentos que tiene el alumno para realizar el examen  
)


# Creación del examen en formato pdf (con las soluciones para revisión) --------------

if (VsalidaPDF) {

set.seed(semilla)  # usar la misma semilla garantiza que sean los mismos ejercicios

exams2pdf(miexamen, 
          n = numcopias,
          # si se quiere un fichero para enunciado solo, y otro fichero para enunciado+solucion
          name = paste0(nombreexamen,c("pdf-enunciados", "pdf-soluciones")),
          # si solamente queremos enunciado+soluciones en un único fichero descomentar siguiente
          # name = paste0(nombreexamen,c("pdf-soluciones")), 
          dir = Vdir, # directorio donde se colocarán los ficheros generados FINALES
          edir = Vedir, # directorio principal del banco de preguntas
          #sdir = Vsdir, # directorio donde se colocarán los ficheros extras generados relacionados con los ejercicios incluidos
          texdir = Vtexdir, # donde se crean los ficheros latex
          template = c("modelos/tempexamnoid.tex", "modelos/tempsolutionnoid.tex"),
          header = list(
            Date = Vfecha,
            ID = function(i) formatC(i, width = 5, flag = "0")
          )
)

}


# Creación del examen en formato html (con las soluciones para revisión) --------------

if (VsalidaHTML) {
  
set.seed(semilla)  # usar la misma semilla garantiza que sean los mismos ejercicios

exams2html(miexamen, 
          n = numcopias, 
          name = paste0(nombreexamen,"html"),
          #name = paste0(nombreexamen,c("html-enunciados")),
          dir = Vdir,   # directorio donde se colocarán los ficheros generados FINALES
          #sdir = Vsdir  # directorio donde se colocarán los ficheros extras generados relacionados con los ejercicios incluidos
          question = "<h4>Pregunta</h4>", 
          solution = "<h4>Solución</h4>",
          #template = c("modelos/tempplain_enunciado.html", "modelos/tempplain_enunsolu.html"),
          mathjax = TRUE, # usa mathjax para mostrar expresiones matemáticas
          edir = Vedir, # directorio principal del banco de preguntas
          
)

}

## ----------------------------------------------------------------------------------
options(exams_tex = oopt$exams_tex)
